==> Scientific.0.8.9.tar.gz: FBEnterprise.framework/Versions/A/Headers/FBProxy.h <==
/* FBProxy.h created by ahoesch on Thu 09-Nov-2000 */
#import <Foundation/Foundation.h>

#define FBGeneralException @"FBGeneralException"

// The following byte definitions are used for IPC to let the connection know what to do. The commands are always one byte long and are followed by parameters in raw format.

// <FBCreateProxyForRootObject>
#define FBCreateProxyForRootObject			1

// < FBCreateProxyForRemoteObject >
//#define FBCreateProxyForRemoteObject			2

// <FBRequestSignatureForSelector> <target> <selector>
#define FBRequestSignatureForSelector			3

// <FBExecuteInvocation> <target> <invocation>
#define FBExecuteInvocation				4

// <FBGoingToReleaseProxyWithRemoteId> <id>
#define FBGoingToReleaseProxyWithRemoteId		5

@class FBConnection;
@class FBPort;

@interface NSObject (FBCodingChecker)

- (BOOL)isCodable;

@end

@interface NSMethodSignature (NSMethodSignatureExtension)

- (NSString *)types;

@end

@interface NSInvocation (NSInvocationExtension)

- (NSData *)encodedArguments;
+ (NSInvocation *)invocationWithMethodSignature:(NSMethodSignature *)signature encodedArguments:(NSData *)encodedArguments port:(FBPort *)port;
- (id)encodedReturnValueWithPort:(FBPort *)port;
- (void)setEncodedReturnValue:(id)encodedReturnValue connection:(FBConnection *)connection;

@end

@interface NSArray (FBCodingChecker)

- (BOOL)isCodable;

@end

@interface NSDictionary (FBCodingChecker)

- (BOOL)isCodable;

@end

@interface NSData (FBConnection)

+ (NSData *)dataForObject:(id)object;
- (id)makeObject;

/*+ (NSData *)dataForSelector:(SEL)selector;
- (SEL)makeSelector;*/

+ (NSData *)messageWithCommand:(int)command exception:(NSException *)exception;
+ (NSData *)messageWithCommand:(int)command parameter:(NSArray *)array;
- (void)extractCommand:(int *)pCommand parameter:(NSArray **)pArray;

+ (NSData *)archiveObject:(id)object;
- (id)unarchivedObject;

@end


@interface FBProxy : NSProxy
{	
   FBConnection *_connection;
   id _remoteObject;
   id _localObject;
   BOOL _isGarbage, _initializing;
}

- (id)initWithTarget:(id)remoteObject connection:(FBConnection *)aConnection;
- (id)initWithLocal:(id)anObject connection:(FBConnection *)aConnection;

- (void)setProtocolForProxy:(Protocol *)aProtocol;
- (id)realObject;
- (id)identifier;
- (BOOL)isRemoteProxy;
- (void)invalidateConnection;

@end

==> Scientific.0.9.tar.gz: FBEnterprise.framework/Versions/A/Headers/FBProxy.h <==
/* FBProxy.h created by ahoesch on Thu 09-Nov-2000 */
#import <Foundation/Foundation.h>

#define FBGeneralException @"FBGeneralException"

// The following byte definitions are used for IPC to let the connection know what to do. The commands are always one byte long and are followed by parameters in raw format.

// <FBCreateProxyForRootObject>
#define FBCreateProxyForRootObject			1

// < FBCreateProxyForRemoteObject >
//#define FBCreateProxyForRemoteObject			2

// <FBRequestSignatureForSelector> <target> <selector>
#define FBRequestSignatureForSelector			3

// <FBExecuteInvocation> <target> <invocation>
#define FBExecuteInvocation				4

// <FBGoingToReleaseProxyWithRemoteId> <id>
#define FBGoingToReleaseProxyWithRemoteId		5

@class FBConnection;
@class FBPort;

/*@interface NSMethodSignature (NSMethodSignatureExtension)

- (NSString *)types;

@end*/

@interface NSInvocation (NSInvocationExtension)

- (NSData *)encodedArguments;
+ (NSInvocation *)invocationWithMethodSignature:(NSMethodSignature *)signature encodedArguments:(NSData *)encodedArguments port:(FBPort *)port;
- (id)encodedReturnValueWithPort:(FBPort *)port;
- (void)setEncodedReturnValue:(id)encodedReturnValue connection:(FBConnection *)connection;

@end

@interface NSArray (FBCodingChecker)

- (BOOL)isCodable;

@end

@interface NSDictionary (FBCodingChecker)

- (BOOL)isCodable;

@end

@interface NSData (FBConnection)

+ (NSData *)encodeProxy:(id)object;
- (id)decodeProxy;

/*+ (NSData *)dataForSelector:(SEL)selector;
- (SEL)makeSelector;*/

+ (NSData *)messageWithCommand:(int)command exception:(NSException *)exception;
+ (NSData *)messageWithCommand:(int)command parameter:(NSArray *)array;
- (void)extractCommand:(int *)pCommand parameter:(NSArray **)pArray;

+ (NSData *)archiveObject:(id)object;
- (id)unarchivedObject;

@end


@protocol FBProxy

- (void)setProtocolForProxy:(Protocol *)aProtocol;

@end

@interface FBProxy : NSProxy < FBProxy >
{	
   FBConnection *_connection;
   id _remoteObject;
   id _localObject;
   Protocol *_protocol;
   BOOL _isGarbage, _initializing;
}

- (id)initWithTarget:(id)remoteObject connection:(FBConnection *)aConnection;
- (id)initWithLocal:(id)anObject connection:(FBConnection *)aConnection;

- (void)setProtocolForProxy:(Protocol *)aProtocol;
- (id)realObject;
- (id)identifier;
- (BOOL)isRemoteProxy;
- (void)invalidateConnection;

@end
